{ config, lib, pkgs, ... }:

let
  unstable = import <nixos-unstable> { config.allowUnfree = true; };
  cloudstation = pkgs.callPackage (import ../packages/cloudstation.nix) { };
  nagstamon =
    pkgs.libsForQt5.callPackage (import ../packages/nagstamon.nix) { };
in {

  environment.variables = {
    USE_GKE_GCLOUD_AUTH_PLUGIN = "True";
  };

  services.tailscale = {
    enable = true;
    package = unstable.tailscale;
  };

  security.pki.certificateFiles = [
    ../dotfiles/certs/NetzmarktCA.crt
    ../dotfiles/certs/vcenter.netzmarkt.lan.crt
  ];

  networking.extraHosts = ''
    10.100.7.11 mon.netzmarkt.de
    85.10.233.162 live.bonedo.de

    172.20.0.2 hubble.kind
    172.20.0.2 dashboard.kind
    172.20.0.2 grafana.kind
    172.20.0.2 alert.kind

    #192.168.2.111 hass.home.f2o.io

    #127.0.0.1 auth-dev.thobits.com
    127.0.0.1 database
    127.0.0.1 youtube.com
    127.0.0.1 www.youtube.com
  '';

  environment.systemPackages = with pkgs; [
    (import ../packages/oc311.nix)
    (import ../packages/oc46.nix)
    (import ../packages/openshift-install-4.5.nix)
    # (import ../packages/vaultsink.nix) needs opensource verson
    cloudstation
    nagstamon
    yubikey-manager
    anydesk
    chromium
    nodejs

    drone-cli
    govc
    ttyd
    unstable.discord
    unstable.go-jira
    (unstable.google-cloud-sdk.withExtraComponents [
      unstable.google-cloud-sdk.components.gke-gcloud-auth-plugin
    ])
    slack
    unstable.velero

    unstable.obs-studio
    unstable.obs-studio-plugins.wlrobs

    unstable.mindustry-wayland
    prusa-slicer
  ];

  # yubikey support
  services.udev.packages = [ pkgs.yubikey-personalization ];
  services.pcscd.enable = true;

}
